@@ -1,7 +1,7 @@
 package Data::Graph::Util;
 
-our $DATE = '2019-02-14'; # DATE
-our $VERSION = '0.005'; # VERSION
+our $DATE = '2019-02-15'; # DATE
+our $VERSION = '0.006'; # VERSION
 
 use 5.010001;
 use strict;
@@ -87,7 +87,7 @@ Data::Graph::Util - Utilities related to graph data structure
 
 =head1 VERSION
 
-This document describes version 0.005 of Data::Graph::Util (from Perl distribution Data-Graph-Util), released on 2019-02-14.
+This document describes version 0.006 of Data::Graph::Util (from Perl distribution Data-Graph-Util), released on 2019-02-15.
 
 =head1 SYNOPSIS
 
@@ -122,6 +122,8 @@ This document describes version 0.005 of Data::Graph::Util (from Perl distributi
 
 Early release. More functions will be added later.
 
+Keywords: topological ordering, dependency sorting, dependency ordering.
+
 =head1 FUNCTIONS
 
 None are exported by default, but they are exportable.
@@ -181,7 +183,13 @@ L<https://en.wikipedia.org/wiki/Graph_(abstract_data_type)>
 
 L<https://en.wikipedia.org/wiki/Topological_sorting#Kahn.27s_algorithm>
 
-L<Sort::Topological> can also sort a DAG, but cannot handle cyclical graph.
+L<Algorithm::Dependency> can also do topological sorting, but it is more finicky
+with input: graph cannot be epmty and all nodes need to be specified.
+
+L<Sort::Topological> can also sort a DAG, but cannot handle cyclical graph. It
+also performs poorly and eats too much RAM on larger graphs.
+
+See L<Bencher::Scenario::GraphTopologicalSortModules> for benchmarks.
 
 =head1 AUTHOR
 
